<?php

return [
    'ciext_parser_alias_callback' => [
        'ehtml'     => 'inlineeditor/parser/parser_ehtml',
        'eimg'      => 'inlineeditor/parser/parser_eimg',
        'elabel'    => 'inlineeditor/parser/parser_elabel',
        'etext'     => 'inlineeditor/parser/parser_etext',
        'evideo_yt' => 'inlineeditor/parser/parser_evideo_yt',
    ],
];