<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Parser_eimg
{
    public function parse($img_full_path, $attributes = '', $i_id = null)
    {
        get_instance()->load->helper('inlineeditor/inline');
        return eimg($img_full_path, (!empty($attributes) ? (array) json_decode($attributes, true) : []), $i_id);
    }
}
